Package: nipalsMCIA
Title: Multiple Co-Inertia Analysis via the NIPALS Method
Version: 1.11.0
Authors@R: c(
    person("Maximilian", "Mattessich",
            email = "maximilian.mattessich@northwestern.edu",
            role = "cre", comment = c(ORCID = "0000-0002-1233-1240")),
    person("Joaquin", "Reyna", email = "joreyna@live.com",
            role = "aut", comment = c(ORCID = "0000-0002-8468-2840")),
    person("Edel", "Aron", email = "edel.aron@yale.edu",
            role = "aut", comment = c(ORCID = "0000-0002-8683-4772")),
    person("Ferhat", "Ay", email = "ferhatay@lji.org",
            role = "aut", comment = c(ORCID = "0000-0002-0708-6914")),
    person("Steven", "Kleinstein", email = "steven.kleinstein@yale.edu",
            role = "aut", comment = c(ORCID = "0000-0003-4957-1544")),
    person("Anna", "Konstorum", email = "konstorum.anna@gmail.com",
            role = "aut", comment = c(ORCID = "0000-0003-4024-2058")))
Description: Computes Multiple Co-Inertia Analysis (MCIA), a
        dimensionality reduction (jDR) algorithm, for a multi-block
        dataset using a modification to the Nonlinear Iterative Partial
        Least Squares method (NIPALS) proposed in (Hanafi et. al,
        2010). Allows multiple options for row- and table-level
        preprocessing, and speeds up computation of variance explained.
        Vignettes detail application to bulk- and single cell-
        multi-omics studies.
License: GPL-3
URL: https://github.com/Muunraker/nipalsMCIA
BugReports: https://github.com/Muunraker/nipalsMCIA/issues
Depends: R (>= 4.3.0)
Imports: ComplexHeatmap, dplyr, fgsea, ggplot2 (>= 3.0.0), graphics,
        grid, methods, MultiAssayExperiment, SummarizedExperiment,
        pracma, rlang, RSpectra, scales, stats
Suggests: BiocFileCache, BiocStyle, circlize, ggpubr, KernSmooth,
        knitr, piggyback, reshape2, rmarkdown, rpart, Seurat (>=
        4.0.0), spatstat.explore, stringr, survival, tidyverse,
        testthat (>= 3.0.0)
VignetteBuilder: knitr
biocViews: Software, Clustering, Classification, MultipleComparison,
        Normalization, Preprocessing, SingleCell
Encoding: UTF-8
RoxygenNote: 7.3.2
Config/testthat/edition: 3
Config/pak/sysreqs: libicu-dev libpng-dev perl zlib1g-dev
Repository: https://bioc.r-universe.dev
Date/Publication: 2026-04-28 13:01:33 UTC
RemoteUrl: https://github.com/bioc/nipalsMCIA
RemoteRef: HEAD
RemoteSha: e4c24cee0df32d41e2b3cca1c4f283b169d4a939
NeedsCompilation: no
Packaged: 2026-05-30 07:30:16 UTC; root
Author: Maximilian Mattessich [cre] (ORCID:
    <https://orcid.org/0000-0002-1233-1240>),
  Joaquin Reyna [aut] (ORCID: <https://orcid.org/0000-0002-8468-2840>),
  Edel Aron [aut] (ORCID: <https://orcid.org/0000-0002-8683-4772>),
  Ferhat Ay [aut] (ORCID: <https://orcid.org/0000-0002-0708-6914>),
  Steven Kleinstein [aut] (ORCID:
    <https://orcid.org/0000-0003-4957-1544>),
  Anna Konstorum [aut] (ORCID: <https://orcid.org/0000-0003-4024-2058>)
Maintainer: Maximilian Mattessich <maximilian.mattessich@northwestern.edu>
Built: R 4.6.0; ; 2026-05-30 10:45:21 UTC; unix
