# Generated by roxygen2: do not edit by hand

export(block_preproc)
export(block_weights_heatmap)
export(cc_preproc)
export(col_preproc)
export(deflate_block_bl)
export(deflate_block_gs)
export(extract_from_mae)
export(get_colors)
export(get_metadata_colors)
export(get_tv)
export(global_scores_eigenvalues_plot)
export(global_scores_heatmap)
export(gsea_report)
export(nipals_iter)
export(nipals_multiblock)
export(nmb_get_bl)
export(nmb_get_bs)
export(nmb_get_bs_weights)
export(nmb_get_eigs)
export(nmb_get_gl)
export(nmb_get_gs)
export(nmb_get_metadata)
export(ord_loadings)
export(predict_gs)
export(projection_plot)
export(simple_mae)
export(vis_load_ord)
export(vis_load_plot)
exportClasses(NipalsResult)
importClassesFrom(MultiAssayExperiment,MultiAssayExperiment)
importFrom(MultiAssayExperiment,assays)
importFrom(MultiAssayExperiment,colData)
importFrom(MultiAssayExperiment,experiments)
importFrom(MultiAssayExperiment,intersectColumns)
importFrom(MultiAssayExperiment,mergeReplicates)
importFrom(RSpectra,svds)
importFrom(SummarizedExperiment,SummarizedExperiment)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(graphics,barplot)
importFrom(graphics,grid)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,segments)
importFrom(methods,is)
importFrom(methods,new)
importFrom(pracma,rand)
importFrom(rlang,quo)
importFrom(scales,viridis_pal)
importFrom(stats,cov)
importFrom(stats,setNames)
importFrom(stats,var)
