#' @name metadata_NCI60
#' @title NCI-60 Multi-Omics Metadata
#' @description Metadata for the included multi-omics dataset, denoting
#' the cancer type associated with each of the 21 cell lines.
#'
#' @references \url{https://github.com/aedin/NCI60Example}
#' @return List with 21 elements
#' @source Meng et. al, 2016 supplementary materials {https://doi.org/10.1093/bib/bbv108}
#' @keywords data multi-omics
NULL
